
*Wordsense*
**---------------------------------------------------------------**

The whole idea of word sense is controversial.
The meaning of a word is highly contextual and depends on its usage in sentence.

English is very difficult language to learn by robot as
a lot of words are Ambiguous( Word with diffrent meanings).

To solve this state-of-the-art problem, we have implemented the solution using Knowledge-Based Method ,
which concerned with identifying which sense of a word is used in a sentence.

**How to Install**

```py
pip install Wordsense
```

**Demonstration**

```py
from wordSense import senses
sentence = 'I went to the bank to deposit my money' 
ambiguous_word = 'bank' 
print (Get_sense(sentence, ambiguous_word))
'a financial institution that accepts deposits and channels the money into lending activities'
```

**Cite**

To cite `Wordsense`:

Anant Dashpute. 2021. Wordsense: Python Implementation of Get_Wordsense.
Retrieved from <https://github.com/DASHANANT/Wordsense>


**References**

- Michael Lesk. 1986. Automatic sense disambiguation using machine readable dictionaries: how to tell a pine cone from an ice cream cone. In Proceedings of the 5th annual international conference on Systems documentation (SIGDOC '86), Virginia DeBuys (Ed.). ACM, New York, NY, USA, 24-26. DOI=10.1145/318723.318728 http://doi.acm.org/10.1145/318723.318728

- Zhi Zhong and Hwee Tou Ng. 2010. It makes sense: a wide-coverage word sense disambiguation system for free text. In Proceedings of the ACL 2010 System Demonstrations. Association for Computational Linguistics, USA, 78–83.

**Suggestions**

Feel free to drop your suggestion at the following email address:

***Author: Anant Dashpute***
***Email: <anantdashpute@gmail.com>***
